==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/app/controllers/user_point_controller.rb <==
# -*- coding: utf-8 -*-
class UserPointController < ApplicationController
  class_desc :display_name => "会員ポイント管理"

  def index
    @condition = prepare_session_condition do |condition|
      condition || UserPoint::SearchInfo.new(params[:condition])
    end
    # 保有ポイントをSQLで計算して表示する必要があったためpaginate_by_sqlを使用しています。
    if @condition.valid?
      per_page = @condition.disp_count ? @condition.disp_count.to_i : 20
      @user_points = UserPoint.paginate_by_sql(
        @condition.create_user_point_find_query(
        ), {:page => params[:page], :per_page => per_page}
      )
    else
      flash[:condition] = @condition
    end
  end

  # ポイント編集画面表示アクション
  # 会員に紐づくポイントを一覧表示して編集します。
  def edit
    user_id = params[:user_id]
    @user = User.find(user_id)
    @total_point = UserPoint.total_point_for_user(params[:user_id])
    @term_date = UserPoint.term_date_for_user(params[:user_id])
    @create_point_error_notice = flash[:create_point_error_notice] || nil
    if flash[:user_points]
      @user_points = flash[:user_points]

    else
      if flash[:create_user_point]
        @create_point = flash[:create_user_point]
      end
      @user_points = UserPoint.find(:all, :conditions => ['user_id = ?', user_id], :order => "user_points.created_at")
    end
    # 0ポイントは空欄表示のため
    @user_points.each do |user_point|
      if user_point.given_point == 0
        user_point.given_point = ""
      end
      if user_point.used_point == 0
        user_point.used_point = ""
      end
    end
  end

  # ポイント情報更新アクション
  def update
    # バリデーションチェック
    valid_flg = true
    user_point_for_save = [] # バリデーションエラー用に出力するuser_point
    user_id = params[:user_id]
    # ポイント一覧を同じ順番にするためもう一度会員でfind
    user_points = UserPoint.find(:all, :conditions => ['user_id = ?', user_id], :order => "user_points.created_at")
    user_points.each do |user_point|
      user_point.attributes = params[:user_points][user_point.id.to_s]
      unless user_point.valid?
        valid_flg = false        
      end
      user_point_for_save << user_point
    end

    unless valid_flg
      flash[:user_points] = user_point_for_save
      return redirect_to :action => 'edit', :page => params[:page], :user_id => params[:user_id]
    end
    user_point_for_save.each do |user_point|
      if user_point.given_point.blank?
        user_point.given_point = 0
      end
      if user_point.used_point.blank?
        user_point.used_point = 0
      end
        user_point.save!
        # 経理テーブルに登録
        Accounting.create_for_point_update(user_point) if user_point.given_point != 0 && user_point.used_point != 0
    end
    redirect_to :action => 'show', :page => params[:page], :user_id => params[:user_id]
  end

  def show
    user_id = params[:user_id]
    @user = User.find(user_id)
    @total_point = UserPoint.total_point_for_user(params[:user_id])
    @term_date = UserPoint.term_date_for_user(params[:user_id])
    @user_points = UserPoint.find(:all, :conditions => ['user_id = ?', user_id], :order => "user_points.created_at")
  end

  # ポイント削除アクション
  def destroy
    user_point = UserPoint.find(params[:id])
    # 経理テーブルに登録
    Accounting.create_for_point_destroy(user_point)
    user_point.destroy
    if params[:edit]
      return redirect_to :action => 'edit', :page => params[:page], :user_id => params[:user_id]
    else
      return redirect_to :action => 'index', :page => params[:page]
    end
  end

  # ポイント新規追加アクション
  def create
    # 有効期限を設定
    point_setting = PointSetting.find(:first)
    user_point = UserPoint.new(params[:create_point])
    user_point.user_id = params[:user_id]
    user_point.term_date = point_setting.create_term_date(Date.today)
    user_point.new_flg = true
    unless user_point.valid?
      flash[:create_user_point] = user_point
      return redirect_to :action => 'edit', :page => params[:page], :user_id => params[:user_id]
    end
    UserPoint.transaction do
      # 有効期限がポイント最終付与時の場合全ポイントの有効期限を付け替え
      unless user_point.term_date.nil?
        UserPoint.term_date_update_for_last_point(params[:user_id], user_point.term_date)
      end
      user_point.save!
      # 経理テーブルに登録
      Accounting.create_for_point_create(user_point)
    end
    return redirect_to :action => 'edit', :page => params[:page], :user_id => params[:user_id]
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/app/controllers/user_point_controller.rb <==
# -*- coding: utf-8 -*-
class UserPointController < ApplicationController
  class_desc :display_name => "会員ポイント管理"

  def index
    @condition = prepare_session_condition do |condition|
      condition || UserPoint::SearchInfo.new(params[:condition])
    end

    if @condition.valid?
      per_page = @condition.disp_count ? @condition.disp_count.to_i : 20
      @user_points = UserPoint.paginate(:all,
        @condition.create_user_point_find_query.update({:page => params[:page], :per_page => per_page, :include => [:order, {:user => :user_address}]})
      )
    else
      flash[:condition] = @condition
    end
  end

  # ポイント編集画面表示アクション
  # 会員に紐づくポイントを一覧表示して編集します。
  def edit
    user_id = params[:user_id]
    @user = User.find(user_id)
    @total_point = UserPoint.total_point_for_user(params[:user_id])
    @term_date = UserPoint.term_date_for_user(params[:user_id])
    @create_point_error_notice = flash[:create_point_error_notice] || nil
    if flash[:user_points]
      @user_points = flash[:user_points]
    else
      if flash[:create_user_point]
        @create_point = flash[:create_user_point]
      end
      @user_points = UserPoint.find(:all, :conditions => ['user_id = ?', user_id], :order => "user_points.created_at")
    end
    # 0ポイントは空欄表示のため
    @user_points.each do |user_point|
      if user_point.given_point == 0
        user_point.given_point = ""
      end
      if user_point.used_point == 0
        user_point.used_point = ""
      end
    end
  end

  # ポイント情報更新アクション
  def update
    # バリデーションチェック
    valid_flg = true
    user_point_for_save = [] # バリデーションエラー用に出力するuser_point
    user_id = params[:user_id]
    # ポイント一覧を同じ順番にするためもう一度会員でfind
    user_points = UserPoint.find(:all, :conditions => ['user_id = ?', user_id], :order => "user_points.created_at")
    user_points.each do |user_point|
      params_user_point = params[:user_points][user_point.id.to_s]
      params_given_point = params_user_point[:given_point].blank? ? "0" : params_user_point[:given_point].to_s
      params_used_point = params_user_point[:used_point].blank? ? "0" : params_user_point[:used_point].to_s
      # DBの値と同じ場合は更新しない。
      next if (user_point.given_point.to_s == params_given_point) && (user_point.used_point.to_s == params_used_point)
      user_point.attributes = params_user_point
      unless user_point.valid?
        valid_flg = false        
      end
      user_point_for_save << user_point
    end

    unless valid_flg
      flash[:user_points] = user_point_for_save
      return redirect_to :action => 'edit', :page => params[:page], :user_id => params[:user_id]
    end
    user_point_for_save.each do |user_point|
      if user_point.given_point.blank?
        user_point.given_point = 0
      end
      if user_point.used_point.blank?
        user_point.used_point = 0
      end
      user_point.save!
      # 経理テーブルに登録
      Accounting.create_for_point_update(user_point) unless (user_point.given_point == 0 && user_point.used_point == 0)
    end
    redirect_to :action => 'show', :page => params[:page], :user_id => params[:user_id]
  end

  def show
    user_id = params[:user_id]
    @user = User.find(user_id)
    @total_point = UserPoint.total_point_for_user(params[:user_id])
    @term_date = UserPoint.term_date_for_user(params[:user_id])
    @user_points = UserPoint.find(:all, :conditions => ['user_id = ?', user_id], :order => "user_points.created_at")
  end

  # ポイント削除アクション
  def destroy
    user_point = UserPoint.find(params[:id])
    # 経理テーブルに登録
    Accounting.create_for_point_destroy(user_point)
    user_point.destroy
    if params[:edit]
      return redirect_to :action => 'edit', :page => params[:page], :user_id => params[:user_id]
    else
      return redirect_to :action => 'index', :page => params[:page]
    end
  end

  # ポイント新規追加アクション
  def create
    # 有効期限を設定
    point_setting = PointSetting.find(:first)
    user_point = UserPoint.new(params[:create_point])
    user_point.user_id = params[:user_id]
    user_point.term_date = point_setting.create_term_date(Date.today)
    user_point.inactive_flg = false
    user_point.new_flg = true
    unless user_point.valid?
      flash[:create_user_point] = user_point
      return redirect_to :action => 'edit', :page => params[:page], :user_id => params[:user_id]
    end
    UserPoint.transaction do
      # 有効期限がポイント最終付与時の場合全ポイントの有効期限を付け替え
      unless user_point.term_date.nil?
        UserPoint.term_date_update_for_last_point(params[:user_id], user_point.term_date)
      end
      user_point.save!
      # 経理テーブルに登録
      Accounting.create_for_point_create(user_point)
    end
    return redirect_to :action => 'edit', :page => params[:page], :user_id => params[:user_id]
  end
end
